@@ -1,7 +1,5 @@
-use strict;
-use warnings;
+use Test2::V0 -no_srand => 1;
 use FFI::Platypus;
-use Test::More;
 use Math::Complex;
 use Test::LeakTrace qw( no_leaks_ok );
 
@@ -21,14 +19,14 @@ my @types = map { ( "sint$_" , "uint$_" ) }
 foreach my $type (@types)
 {
   subtest $type => sub {
-    my $ffi = FFI::Platypus->new( api => 1, experimental => 1 );
+    my $ffi = FFI::Platypus->new( api => 1 );
     my $f = $ffi->function(0 => [] => "object(Foo,$type)" );
     no_leaks_ok { $f->call };
   }
 }
 
 subtest 'opaque' => sub {
-  my $ffi    = FFI::Platypus->new( api => 1, experimental => 1, lib => [undef] );
+  my $ffi    = FFI::Platypus->new( api => 1, lib => [undef] );
   my $malloc = $ffi->function( malloc => [ 'size_t' ] => 'opaque' );
   my $free   = $ffi->function( free => [ 'opaque' ] => 'void' );
   my $ptr    = $malloc->call(200);
