@@ -7,8 +7,7 @@ typedef struct {
 } foo_t;
 
 foo_t*
-foo__new(const char *class_name, const char *name, int value)
-{
+foo__new(const char *class_name, const char *name, int value) {
   (void)class_name;
   foo_t *self = malloc( sizeof( foo_t ) );
   self->name = strdup(name);
@@ -17,20 +16,17 @@ foo__new(const char *class_name, const char *name, int value)
 }
 
 const char *
-foo__name(foo_t *self)
-{
+foo__name(foo_t *self) {
   return self->name;
 }
 
 int
-foo__value(foo_t *self)
-{
+foo__value(foo_t *self) {
   return self->value;
 }
 
 void
-foo__DESTROY(foo_t *self)
-{
+foo__DESTROY(foo_t *self) {
   free(self->name);
   free(self);
 }
